// ******************************************************************
//
// File Name   : process_measurements.c
// Author      : D. Festing
// Created     : 19/9/2015
// Revised     : 
// Version     : 1.0
// Target MCU  : Atmel AVR series
// Editor Tabs	: 3
//
// Description : This file contains the functions that acquire the data and
//               process it.
//
// ******************************************************************


#include "project.h" // has to be the first header file
#include "process_measurements.h"


// ******************************************************************
//
// Function Name: get_ADC_value();   
// Description:        
// Preconditions:     
// Input Parameters: None 
// Return Parameter: None 
// Effects:           
//
// ******************************************************************
uint16_t get_ADC_value(void)
{
   uint16_t averaged_ADC_value = 0;
   uint16_t temp_buf[NUMBER_OF_SAMPLES];
   uint8_t buf_index = 0;
   uint16_t result = 0;


// discarding the first conversion seems to be a common approach
   ADCSRA |= (1<<ADSC);        // start a/d conversion
   while(ADCSRA & (1<<ADSC)) ; // wait while ADSC bit is high

// Store each sample to buffer   
   for(buf_index = 0; buf_index < NUMBER_OF_SAMPLES; buf_index++)
   {
      ADCSRA |= (1<<ADSC);        // start a/d conversion
      while(ADCSRA & (1<<ADSC)) ; // wait while ADSC bit is high
     
      temp_buf[buf_index] = ADC; // 10 bits in 2 registers
   }

// average the samples
   for(buf_index = 0; buf_index < NUMBER_OF_SAMPLES; buf_index++)
   {
      result += temp_buf[buf_index];
   }

   averaged_ADC_value = result / NUMBER_OF_SAMPLES;

   return averaged_ADC_value; 
}
/* ---------- end of get_ADC_value() ---------- */
